@@ -1,7 +1,7 @@
 from dataclasses import dataclass, field
 from typing import List, Callable
 
-from .helper import change_page, initialize, read_page
+from .helper import change_page, initialize, read_page, load
 
 import streamlit as st
 
